summaryrefslogtreecommitdiffstats
path: root/Guard/GuardAuthenticatorInterface.php
diff options
context:
space:
mode:
Diffstat (limited to 'Guard/GuardAuthenticatorInterface.php')
-rw-r--r--Guard/GuardAuthenticatorInterface.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/Guard/GuardAuthenticatorInterface.php b/Guard/GuardAuthenticatorInterface.php
index 0b4306c..4b1e407 100644
--- a/Guard/GuardAuthenticatorInterface.php
+++ b/Guard/GuardAuthenticatorInterface.php
@@ -44,13 +44,13 @@ interface GuardAuthenticatorInterface extends AuthenticationEntryPointInterface
*
* @return mixed|null
*/
- public function getCredentialsFromRequest(Request $request);
+ public function getCredentials(Request $request);
/**
* Return a UserInterface object based on the credentials OR throw
* an AuthenticationException.
*
* The *credentials* are the return value from getCredentialsFromRequest()
*
* @param mixed $credentials
* @param UserProviderInterface $userProvider
@@ -44,13 +44,13 @@ interface GuardAuthenticatorInterface extends AuthenticationEntryPointInterface
* an AuthenticationException.
*
- * The *credentials* are the return value from getCredentialsFromRequest()
+ * The *credentials* are the return value from getCredentials()
*
* @param mixed $credentials